% Matlab Mistuning Code: Version 2.0
%
% Created by: Benjamin Shapiro,
%             Control and Dynamical Systems
%             California Institute of Technology
%             Pasadena, CA 91125.
%             bshapiro@indra.caltech.edu
%
%
%   Copyright (c) 1998, California Institute of Technology.
%   Permission is granted to copy, modify, and redistribute
%   this software provided all header messages are retained.
%
% *********************************************************
%
% File: Error.m
% Purpose: Compare exact (specific z) to approximate (valid
%   for any z) eigenvalues.
% Last Update: 06/12/98 by B.Shapiro
%
% *********************************************************

% Clear eigenvalue array:
  steps = 45;
  ExactEig = zeros(1,r*d*steps);
  ApproxEig = zeros(1,r*d*steps);


% Initialize M(y)
  clear Mofy;
  Mofy = zeros(r*d,r*d);


% Choose a vector Y:
  md = 1;  % the mode
  Y = cos( (2*pi*md/r) * [1:1:r] );


% START LOOP HERE:
  sz = 0; % size
  incr = 0.00033;
  for i = 1:steps

    % define scaled mistuning
      sz = sz + incr;
      y = sz*Y;

    % Construct M(y)
    Mofy(1:d,:) = double( subs(Mrow,z,y) );
    for j = 1:r-1
       Mofy(j*d+1:(j+1)*d,:) = ...
                double( rot( subs( Mrow, z, rot(y,j,1,r) )  ,r-j,d,r) );
    end

    % Compute the eigenvalues of M(y): exact vs approx.
      TempExactEig = eig( Mofy ).';
      TempAppEig = EigenTun + EigenSec(y,a,b,c,r);
      % These won't be in the same order!
  
      ExactEig(1,(i-1)*r*d+1:i*r*d) = TempExactEig;
      ApproxEig(1,(i-1)*r*d+1:i*r*d) = TempAppEig;


  end
% END LOOP






% PLOT COMPARING EXACT vs APPROXIMATE MISTUNED EIGENVALUES

% Make plot title:
mdstr = num2str(md);
incstr = num2str(incr);
sizestr = num2str(sz);
titlestr = ...
['Mistuned Eigenvalue Comparison: mode ' mdstr ', incr ' incstr ', max-size ' sizestr];

% Plot eigenvalue comparison:
xmin = 1.25 * min( real( EigenTun ) );
xmax = max( 0, max( real( EigenTun ) ) );
ymax = max( imag( EigenTun ) );
ymin = min( abs( imag( EigenTun ) ) );
delta = ymax - ymin;
ymax = ymax + delta/4;
ymin = ymin - delta/4;
  clf;
  plot( real(EigenTun), imag(EigenTun), 'r*', ... 
        real(ExactEig), imag(ExactEig), 'r.', ... 
        real(ApproxEig), imag(ApproxEig), 'b.' )
  title(titlestr);
  axis([xmin xmax ymin ymax]);
  xlabel('real');
  ylabel('imag');
  legend('Tuned','Exact Mistuned','2nd order approx.');
  addinfo('',date,'Complex conjugates not shown.','MAST: B. Shapiro, Caltech');
clear xmin xmax ymin ymax delta x y h j k;
% End plot eigenvalues comparison.
% Print plot to file:
  print -depsc Outputs/EigComp.eps

% Save plot data:
  savedon = date;
  save('Outputs/eigcomp','EigenTun','ExactEig','ApproxEig',...
                        'md','incr','steps','sz','savedon')
