% Matlab Mistuning Code: Version 2.0
%
% Created by: Benjamin Shapiro,
%             Control and Dynamical Systems
%             California Institute of Technology
%             Pasadena, CA 91125.
%             bshapiro@indra.caltech.edu
%
%   Copyright (c) 1998, California Institute of Technology.
%   Permission is granted to copy, modify, and redistribute
%   this software provided all header messages are retained.
%
% *********************************************************
%
% File: ErrorZoom.m
% Purpose: Compare exact (specific z) to approximate (valid
%   for any z) eigenvalues. Zoom version of Error.m
% Last Update: 06/12/98 by B.Shapiro
%
% *********************************************************


% Load data of Error.m
load('Outputs/eigcomp')  % Load previous plot.


% Zoom plots:
  zoom = 25;
% At:
  xzoom = -0.0435;
  yzoom = 1.0165;


% Make plot title:
mdstr = num2str(md);
incstr = num2str(incr);
sizestr = num2str(incr*steps);
titlestr = ...
['Mistuned Eigenvalue Comparison: mode ' mdstr ', incr ' incstr ', max-size ' sizestr];


% Plot eigenvalue comparison:
% Old plot bounds:
xmin = 1.25 * min( real( EigenTun ) );
xmax = max( 0, max( real( EigenTun ) ) );
dx = (xmax-xmin)/zoom;
ymax = max( imag( EigenTun ) );
ymin = min( abs( imag( EigenTun ) ) );
delta = ymax - ymin;
ymax = ymax + delta/4;
ymin = ymin - delta/4;
dy = (ymax-ymin)/zoom;
% Defined zoomed bounds:
  xmin = xzoom - dx/2;
  xmax = xzoom + dx/2;
  ymin = yzoom - dy/2;
  ymax = yzoom + dy/2;

  plot( real(EigenTun), imag(EigenTun), 'r*', ... 
        real(ExactEig), imag(ExactEig), 'r.', ... 
        real(ApproxEig), imag(ApproxEig), 'b.' )
  title(titlestr);
  axis([xmin xmax ymin ymax]);
  xlabel('real');
  ylabel('imag');
  legend('Tuned','Exact Mistuned','2nd order approx.',3);
  addinfo('',date,'Complex conjugates not shown.','MAST: B. Shapiro, Caltech');
clear xmin xmax ymin ymax delta x y h j k;
% End plot eigenvalues comparison.
% Print plot to file:
  print -depsc Outputs/EigCompZoom.eps
