% Matlab Mistuning Code: Version 1.0
%
% Created by: Benjamin Shapiro,
%             Control and Dynamical Systems
%             California Institute of Technology
%             Pasadena, CA 91125.
%             bshapiro@indra.caltech.edu
%
% *********************************************************
%
% File: Mistuning.m
% Purpose: Main file, runs the mistuning code.
% Last Update: 04/22/98 by B.Shapiro
%
% *********************************************************

clear
tic

% Heading output:
  fprintf('\n')
  fprintf('\t MISTUNING SOFTWARE: Version 1.0 \n')
  fprintf('\n')
  fprintf('\t Created: Benjamin Shapiro \n')
  fprintf('\t \t  Control and Dynamical Systems \n')
  fprintf('\t \t  Caltech, Pasadena, CA 91125 \n')
  fprintf('\t \t  bshapiro@indra.caltech.edu \n')
  fprintf('\n')
  fprintf('\t Copyright: B. Shapiro, Caltech. \n')
  fprintf('\n')
  fprintf('\n')




% ********************************************************
% USER INPUT: 
%
%  User defined flags:

   new = 1;  % 0 = load old model.
             % 1 = evaluate new model.

   hots = 0; % 0 = perturb eigenvectors/values to
             %     1rst/2nd order in mistuning z---
             %     leading order. (Will be inaccurate if
             %     [tuned eigenvalues almost indistinct
             %     compared to mistuning] equivalently 
             %     [if mistuning large compared to 
             %     aerodynamics].)
             % 1 = perturb eigenvectors/values to
             %     2nd/3rd order in mistuning z.
             %     Accuracy better but code takes more
             %     time to run. NOT ACTIVE RIGHT NOW,
             %     PLEASE WAIT FOR NEXT RELEASE: 04/22/98.
             %
             % NOTE: Only active if new = 1, otherwise will
             % use the hots value saved in old-model. If you
             % change hots you must rerun the model (new = 1).

   stab_out = 0; % 0 = Do not display stability data and
                 %     write results to file.
                 % 1 = Display stability data and write 
                 %     results to file. 
                 % 
                 % NOTE: If you are REWRITING stability information, 
                 % please first remove all files "Eigval:*" in 
                 % "Outputs/StabData". Otherwise data will be written
                 % twice in each file "Eigval:i,j".

   unix_machine = 1; % 0 = Not on a unix platform.
                     % 1 = On a unix machine:
                     %      Matlab will automatically delete old files
                     %      before writing new results. If you are on a
                     %      PC, Mac or some other platform, the files
                     %      "Outputs/StabData/Eigval:*" should be deleted
                     %      manually before each new run. Otherwise data 
                     %      will be written twice in each file "Eigval:i,j".

% END USER INPUT
% *********************************************************



% BEGIN GENERATE MODEL:
  if new 
    model                  % New model from file: model.m
  else
    load('Data/modelvar')  % Load old model from: Data/modelvar.mat
      fprintf('Loading model saved on %s. \n',savedon) 
  end

  % Output for model
  fprintf('\t Model has %g blades with %g states per blade. \n', r, d )
    if linmodel == 1 
       fprintf('\t It is linear in mistuning vector z. \n')
    else
       fprintf('\t It is nonlinear in mistuning vector z. \n')
    end
    if exist('savemodel') & savemodel 
       fprintf('\t Results saved to: Data/modelvar.mat \n')
    end
  fprintf('\n')
% END GENERATE MODEL

    % Time at finished model:
    etime = toc;
    fprintf('\t \t \t Elapsed time: %f minutes. \n', etime/60 )
    fprintf('\n')



% Print which perturbation method
  fprintf('Chosen perturbation method: \n')
    if hots
      fprintf('\t Eigenvectors/values will be perturbed to \n')
      fprintf('\t second/third order in mistuning z. \n')
      fprintf('\n')
    else
      fprintf('\t Eigenvectors/values will be perturbed to \n')
      fprintf('\t first/second order in mistuning z. \n')
      fprintf('\n')
    end


% Compute tuned eigenval/vect:
  tuneigen

    % Time when finished computing tuned eigenvalues/vectors:
    etime = toc;
    fprintf('\n')
    fprintf('\t \t \t Elapsed time: %f minutes. \n', etime/60 )

% Build mistuned eigenvalue/vector perturbations
  perturb

    % Time when finished computing tuned eigenvalues/vectors:
    etime = toc;
    fprintf('\n')
    fprintf('\t \t \t Elapsed time: %f minutes. \n', etime/60 )

% Print stability output to file
  if stab_out  
     stability
       % Time when finished writing stability data:
       etime = toc;
       fprintf('\n')
       fprintf('\t \t \t Elapsed time: %f minutes. \n', etime/60 )
  end

