    % Model Parameters: Here r = 11, d = 3.
    k = 150000;           % blade stiffness
    m = 0.05;             % blade mass
    rho = 1.23;           % air density
    alpha = 0.1;          % angle of attack
    ch = 0.080;           % blade chord 
    el = 0.078;           % effective blade length
    y = 1/2;              % lag weight (if one recover unlagged)
    tau = 3.3333;         % lag time.
    wn = sqrt(k/m);       % natural freq.
    L = (rho*ch^2)/(2*m); % lift coeff.
    U = 23.1579;          % loading.

    % Brianno's aerodynamic coeff.
    e = [6.3573 -0.3316 0.1062 0.0958 0.0668 0.0325 ...
         -0.0054 -0.0551 -0.1413 -0.3398 -1.4943];
    f = [0.2196 1.1274 0.0452 -0.0035 -0.0050 -0.0125 ...
         -0.0128 -0.0233 -0.0428 -0.1295 -1.1629];
    

    % Diagonal block:
    M1 = [              0                           1               0;
          -(1+z1)/(U^2)+el*L*sin(alpha)*f(1)  -el*L*y*e(1)  -el*L*e(1)*(1-y);
                        0                      2*U*wn/tau     -2*U*wn/tau   ];
 
    % Off-diagonal blocks:
    for j = 2:r
      Mtemp = [         0                0                0; 
               f(j)*el*L*sin(alpha) -e(j)*el*L*y  -e(j)*el*L*(1-y);
                        0                0                0       ];
      eval(['M' num2str(j) ' = Mtemp;'])
    end
 
    % Forcing vector
    beta = [ 0;
             0.1*el*L*pi;
             0];
  
    % Please clear intermediate constants to avoid later conflicts:
    clear k m rho alpha ch el y tau wn U L e f;


