function x = Xsec(z,l,w)
% Yields X(z,w) the mistuned response of 
% ALL BLADES: correct up to first order 
% in eigenvectors and second order in 
% eigenvalues. Outputs a rd sized vector.
%
% As in EigenSec.m, do not use symbolic z's,
% Matlab cannot handle r^2 symbolic variables. 
%
%   Copyright (c) 1998, California Institute of Technology.
%   Permission is granted to copy, modify, and redistribute
%   this software provided all header messages are retained.


clear i;

% Get global variables:
  global PSI0;
  global DPSI;
  global EigenTun;
  global a;
  global b;
  global c;
  global d;
  global r;
% Got globals.


% Initialize
  x = zeros(r*d,1);    % resp. for all blades.
  Psiz = zeros(r*d,1); % Psi(z) for all blades.
  delta_Eig = EigenSec(z,a,b,c,r); % 2nd order change in eigenvals by mist.


% Sum over all modes.
  for j = 1:r*d
    % Compute Psi(z) = Psiz = PSI0 + DPSI.z
      Psiz = PSI0(:,j) + DPSI(:,:,j)*z';
    % Got Psiz.
  
    % Now compute: X(z,w) = Psi(z)/(iw-lambda(z)).
      x = x + Psiz/(i*w -EigenTun(j) -delta_Eig(j) );
    % Got X(z,w)
  end
% Got all modes.



% B. Shapiro, Caltech, 04/28/98.
